(****************************************)
(* ITA Office97 Style Components        *)
(* Version 1.5                          *)
(*                                      *)
(****************************************)
(* (c) 1996-98 ITA Software Labs        *)
(* All right reserved.                  *)
(*                                      *)
(****************************************)
(* Internet: aepp@vsgtu.eastsib.ru      *)
(* WWW:                                 *)
(*   http://www.ita.eastsib.ru          *)
(*   http://i-connect.ru/~ita           *)                  
(****************************************)
unit ita_o97reg;

interface

uses Classes, Menus, dialogs, DsgnIntf;

procedure Register;

implementation {===========================================================}

uses ita_Office97, pm97frm, sb97frm, cb97frm, Controls, ita_common;

{ TToolBarEditor }

type

  TGlyphsProperty = class(TPropertyEditor)
  public
    procedure Edit; override;
    function GetAttributes: TPropertyAttributes; override;
    function GetValue: string; override;
    procedure SetValue(const Value: string); override;
  end;

  TGlyphIndexProperty = class(TPropertyEditor)
  public
    procedure Edit; override;
    function GetAttributes: TPropertyAttributes; override;
    function GetValue: string; override;
    procedure SetValue(const Value: string); override;
  end;

  TGlyphIndexProperty2 = class(TPropertyEditor)
  public
    procedure Edit; override;
    function GetAttributes: TPropertyAttributes; override;
    function GetValue: string; override;
    procedure SetValue(const Value: string); override;
  end;

  TToolBarEditor = class(TDefaultEditor)
    procedure ExecuteVerb(Index: Integer); override;
    function GetVerb(Index: Integer): string; override;
    function GetVerbCount: Integer; override;
  end;

  TMenuBarEditor = class(TDefaultEditor)
    procedure ExecuteVerb(Index: Integer); override;
    function GetVerb(Index: Integer): string; override;
    function GetVerbCount: Integer; override;
  end;

{ TGlyphs ====================================== }

procedure TGlyphsProperty.Edit;
var
  GlyphsForm: TfrmGlyphs;
  Comp: TitaOfficePopupMenu;
begin
  GlyphsForm := TfrmGlyphs.Create(nil);
  try
    Comp := TitaOfficePopupMenu(GetComponent(0));
    If Comp.Glyphs = nil Then
      MsgError('You mast insert TGlyph component on the form.')
    else
    begin
      Glyphsform.Caption := Comp.Name + '.' +
        GetName + ' - ' + GlyphsForm.Caption;
      GlyphsForm.SetItems(Comp, Comp.Glyphs);
      GlyphsForm.ShowModal;
    end;
  finally
    GlyphsForm.Free;
  end;
end;

function TGlyphsProperty.GetAttributes: TPropertyAttributes;
begin
  Result := [paDialog];
end;

function TGlyphsProperty.GetValue: string;
begin
  Result := '(Edit)';
end;

procedure TGlyphsProperty.SetValue(const Value: string);
begin
  if Value = '' then SetOrdValue(0);
end;

{ TGlyphIndex ====================================== }

procedure TGlyphIndexProperty.Edit;
var
  SBGlyphsForm: TfrmSBGlyphs;
  Comp: TitaSpeedButton;
begin
  SBGlyphsForm := TfrmSBGlyphs.Create(nil);
  try
    Comp := TitaSpeedButton(GetComponent(0));
    If Comp.Glyphs = nil Then
      MsgError('Property Glyphs must not empty.')
    else
    begin
      SBGlyphsform.Caption := Comp.Name + '.' +
        GetName + ' - ' + SBGlyphsForm.Caption;
      SBGlyphsForm.SetItems(Comp, Comp.Glyphs);
      SBGlyphsForm.ShowModal;
    end;
  finally
    SBGlyphsForm.Free;
  end;
end;

function TGlyphIndexProperty.GetAttributes: TPropertyAttributes;
begin
  Result := [paDialog];
end;

function TGlyphIndexProperty.GetValue: string;
begin
  Result := '(Index)';
end;

procedure TGlyphIndexProperty.SetValue(const Value: string);
begin
  if Value = '' then SetOrdValue(0);
end;

{ TGlyphIndex2 ====================================== }

procedure TGlyphIndexProperty2.Edit;
var
  CBGlyphsForm: TfrmCBGlyphs;
  Comp: TitaComboButton;
begin
  CBGlyphsForm := TfrmCBGlyphs.Create(nil);
  try
    Comp := TitaComboButton(GetComponent(0));

    If Comp.Glyphs = nil Then
      MsgError('Property Glyphs must not empty.')
    else
    begin
      CBGlyphsform.Caption := Comp.Name + '.' +
        GetName + ' - ' + CBGlyphsForm.Caption;
      CBGlyphsForm.SetItems(Comp, Comp.Glyphs);
      CBGlyphsForm.ShowModal;
    end;
  finally
    CBGlyphsForm.Free;
  end;
end;

function TGlyphIndexProperty2.GetAttributes: TPropertyAttributes;
begin
  Result := [paDialog];
end;

function TGlyphIndexProperty2.GetValue: string;
begin
  Result := '(Index)';
end;

procedure TGlyphIndexProperty2.SetValue(const Value: string);
begin
  if Value = '' then SetOrdValue(0);
end;

{ TToolbar ============================================== }

const
  ToolBarVerbs: array[0..5] of String = ('New separator', 'New button',
                'New combo button', 'New popup button',
                'New combo popup button', 'New color combo button');

procedure TToolBarEditor.ExecuteVerb(Index: Integer);
var
  ToolBar: TitaToolBar;
  Tool: TControl;
  Designer: TFormDesigner;
begin
  If Component is TitaToolBar Then
    ToolBar := Component as TitaToolBar
  else
    If (Component is TControl) Then
      ToolBar := (Component as TControl).Parent as TitaToolBar
    else
      ToolBar := nil;

  if ToolBar <> nil then
  begin
    Designer := Self.Designer;
    Tool := nil;
    case Index of
    0:begin
        Tool := TTBSeparator.Create(Designer.Form);
        try
          Tool.Name := Designer.UniqueName(TTBSeparator.ClassName);
          Tool.Parent := ToolBar;
        except
          Tool.Free;
          raise;
        end;
      end;
    1:begin
        Tool := TTBButton.Create(Designer.Form);
        try
          Tool.Name := Designer.UniqueName(TTBButton.ClassName);
          Tool.Parent := ToolBar;
        except
          Tool.Free;
          raise;
        end;
      end;
    2:begin
        Tool := TTBCombo.Create(Designer.Form);
        try
          Tool.Name := Designer.UniqueName(TTBCombo.ClassName);
          Tool.Parent := ToolBar;
        except
          Tool.Free;
          raise;
        end;
      end;
    3:begin
        Tool := TTBPopup.Create(Designer.Form);
        try
          Tool.Name := Designer.UniqueName(TTBPopup.ClassName);
          Tool.Parent := ToolBar;
        except
          Tool.Free;
          raise;
        end;
      end;
    4:begin
        Tool := TTBComboPopup.Create(Designer.Form);
        try
          Tool.Name := Designer.UniqueName(TTBComboPopup.ClassName);
          Tool.Parent := ToolBar;
        except
          Tool.Free;
          raise;
        end;
      end;
    5:begin
        Tool := TTBColorCombo.Create(Designer.Form);
        try
          Tool.Name := Designer.UniqueName(TTBColorCombo.ClassName);
          Tool.Parent := ToolBar;
        except
          Tool.Free;
          raise;
        end;
      end;
    end;
    If Tool <> nil Then
      If ToolBar.Parent.Align in [alTop, alBottom] Then
      begin
        Tool.Left := ToolBar.Width;
        Tool.Align := alLeft;
      end
      else
      begin
        Tool.Top := ToolBar.Height;
        Tool.Align := alTop;
      end;
    ToolBar.Aligning;
    Designer.SelectComponent(Tool);
    Designer.Modified;
  end;
end;

function TToolBarEditor.GetVerb(Index: Integer): string;
begin
  Result := ToolBarVerbs[Index];
end;

function TToolBarEditor.GetVerbCount: Integer;
begin
  Result := High(ToolBarVerbs) + 1;
end;

{ TMenuBar ============================================== }

procedure TMenuBarEditor.ExecuteVerb(Index: Integer);
var
  MenuBar: TitaMenuBar;
  Tool: TControl;
  Designer: TFormDesigner;
begin
  If Component is TitaToolBar Then
    MenuBar := Component as TitaMenuBar
  else
    If (Component is TControl) Then
      MenuBar := (Component as TControl).Parent as TitaMenuBar
    else
      MenuBar := nil;

  if MenuBar <> nil then
  begin
    Designer := Self.Designer;
    Tool := nil;
    case Index of
    0:begin
        Tool := TitaMenuButton.Create(Designer.Form);
        try
          Tool.Name := Designer.UniqueName(TitaMenuButton.ClassName);
          Tool.Parent := MenuBar;
        except
          Tool.Free;
          raise;
        end;
      end;
    end;
    If Tool <> nil Then
      If MenuBar.Parent.Align in [alTop, alBottom] Then
      begin
        Tool.Left := MenuBar.Width;
        Tool.Align := alLeft;
      end
      else
      begin
        Tool.Top := MenuBar.Height;
        Tool.Align := alTop;
      end;
    MenuBar.Aligning;
    Designer.SelectComponent(Tool);
    Designer.Modified;
  end;
end;

function TMenuBarEditor.GetVerb(Index: Integer): string;
begin
  Result := 'New Menu Button';
end;

function TMenuBarEditor.GetVerbCount: Integer;
begin
  Result := 1;
end;

{ Registration }

procedure Register;
begin
  RegisterComponents('ITA Office97',
  [
// Glyphs //
    TitaGlyphs,
// Menus //
    TitaMenuBar,
    TitaOfficePopupMenu,
    TitaColorMenu,
    TitaMenuButton,
// Buttons //
    TitaSpeedButton,
    TitaComboButton,
    TitaPopupButton,
    TitaComboPopupButton,
    TitaColorComboButton,
// Lists //
    TitaColorComboBox,
    TitaFontComboBox,
// ToolBar //
    TitaDock,
    TitaToolBar,
// Assistan //
    TitaAssistan,
    TitaAssistanMoves,
    TitaAssistanSetupDialog,
    TitaAssistanKind,
    TitaAssistPanel,
    TitaAssistButton,
    TitaAssistLine
  ]);

  RegisterClass(TTBSeparator);
  RegisterClass(TTBButton);
  RegisterClass(TTBCombo);
  RegisterClass(TTBPopup);
  RegisterClass(TTBComboPopup);
  RegisterClass(TTBColorCombo);

  RegisterComponentEditor(TitaToolBar, TToolBarEditor);
  RegisterComponentEditor(TitaMenuBar, TMenuBarEditor);
  RegisterPropertyEditor(TypeInfo(Integer), TitaCustomPopupMenu, 'GlyphsEdit',
    TGlyphsProperty);
  RegisterPropertyEditor(TypeInfo(Integer), TitaSpeedButton, 'GlyphIndex',
    TGlyphIndexProperty);
  RegisterPropertyEditor(TypeInfo(Integer), TitaComboButton, 'GlyphIndex',
    TGlyphIndexProperty2);
end;

end.
